@@ -17,13 +17,6 @@ describe 'neutron::server' do
       :package_ensure           => 'present',
       :enabled                  => true,
       :auth_strategy            => 'keystone',
-      :database_connection      => 'sqlite:////var/lib/neutron/ovs.sqlite',
-      :database_max_retries     => 10,
-      :database_idle_timeout    => 3600,
-      :database_retry_interval  => 10,
-      :database_min_pool_size   => 1,
-      :database_max_pool_size   => 10,
-      :database_max_overflow    => 20,
       :sync_db                  => false,
       :router_scheduler_driver  => 'neutron.scheduler.l3_agent_scheduler.ChanceScheduler',
       :l3_ha                    => false,
@@ -56,18 +49,39 @@ describe 'neutron::server' do
     end
 
     it 'configures neutron server service' do
-      should contain_service('neutron-server').with(
-        :name    => platform_params[:server_service],
-        :enable  => true,
-        :ensure  => 'running',
-        :tag     => ['neutron-service', 'neutron-db-sync-service', 'neutron-server-eventlet'],
-      )
-      should contain_service('neutron-server').that_subscribes_to('Anchor[neutron::service::begin]')
-      should contain_service('neutron-server').that_notifies('Anchor[neutron::service::end]')
+      if platform_params.has_key?(:server_service)
+        should contain_service('neutron-server').with(
+          :name    => platform_params[:server_service],
+          :enable  => true,
+          :ensure  => 'running',
+          :tag     => ['neutron-service', 'neutron-db-sync-service', 'neutron-server-eventlet'],
+        )
+        should contain_service('neutron-server').that_subscribes_to('Anchor[neutron::service::begin]')
+        should contain_service('neutron-server').that_notifies('Anchor[neutron::service::end]')
+      else
+        should contain_service('neutron-api').with(
+          :name    => platform_params[:api_service_name],
+          :enable  => true,
+          :ensure  => 'running',
+          :tag     => ['neutron-service', 'neutron-db-sync-service', 'neutron-server-eventlet'],
+        )
+        should contain_service('neutron-api').that_subscribes_to('Anchor[neutron::service::begin]')
+        should contain_service('neutron-api').that_notifies('Anchor[neutron::service::end]')
+
+        should contain_service('neutron-rpc-server').with(
+          :name    => platform_params[:rpc_service_name],
+          :enable  => true,
+          :ensure  => 'running',
+          :tag     => ['neutron-service', 'neutron-db-sync-service'],
+        )
+        should contain_service('neutron-rpc-server').that_subscribes_to('Anchor[neutron::service::begin]')
+        should contain_service('neutron-rpc-server').that_notifies('Anchor[neutron::service::end]')
+      end
+
       should_not contain_class('neutron::db::sync')
-      should contain_service('neutron-server').with_name('neutron-server')
       should contain_neutron_config('DEFAULT/api_workers').with_value(facts[:os_workers])
       should contain_neutron_config('DEFAULT/rpc_workers').with_value(facts[:os_workers])
+      should contain_neutron_config('DEFAULT/rpc_state_report_workers').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/rpc_response_max_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/agent_down_time').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/enable_new_agents').with_value('<SERVICE DEFAULT>')
@@ -76,7 +90,8 @@ describe 'neutron::server' do
         :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
         :max_request_body_size        => '<SERVICE DEFAULT>',
       )
-      should contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_config('ovs/integration_bridge').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_config('ovs/igmp_snooping_enable').with_value('<SERVICE DEFAULT>')
     end
 
     context 'with manage_service as false' do
@@ -85,7 +100,12 @@ describe 'neutron::server' do
       end
 
       it 'should not start/stop service' do
-        should contain_service('neutron-server').without_ensure
+        if platform_params.has_key?(:server_service)
+          should contain_service('neutron-server').without_ensure
+        else
+          should contain_service('neutron-api').without_ensure
+          should contain_service('neutron-rpc-server').without_ensure
+        end
       end
     end
 
@@ -224,7 +244,11 @@ describe 'neutron::server' do
 
     context 'when running neutron-api in wsgi' do
       before :each do
-        params.merge!( :service_name => 'httpd' )
+        params.merge!(
+          :service_name     => false,
+          :api_service_name => 'httpd',
+          :rpc_service_name => 'neutron-rpc-server',
+        )
       end
 
       let :pre_condition do
@@ -236,11 +260,27 @@ describe 'neutron::server' do
       end
 
       it 'configures neutron-api service with Apache' do
-        should contain_service('neutron-server').with(
-          :ensure     => 'stopped',
-          :name       => platform_params[:server_service],
-          :enable     => false,
-          :tag        => ['neutron-service', 'neutron-db-sync-service'],
+        if platform_params.has_key?(:server_service)
+          should contain_service('neutron-server').with(
+            :ensure     => 'stopped',
+            :name       => platform_params[:server_service],
+            :enable     => false,
+            :tag        => ['neutron-service'],
+          )
+        else
+          should contain_service('neutron-api').with(
+            :ensure     => 'stopped',
+            :name       => platform_params[:api_service_name],
+            :enable     => false,
+            :tag        => ['neutron-service'],
+          )
+        end
+
+        should contain_service('neutron-rpc-server').with(
+          :ensure => 'running',
+          :name   => 'neutron-rpc-server',
+          :enable => true,
+          :tag    => ['neutron-service', 'neutron-db-sync-service'],
         )
       end
     end
@@ -265,21 +305,29 @@ describe 'neutron::server' do
         params.merge!({:ovs_integration_bridge => 'br-int' })
       end
 
-      it { should contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('br-int') }
+      it { should contain_neutron_config('ovs/integration_bridge').with_value('br-int') }
+    end
+
+    context 'with IGMP snooping enabled' do
+      before :each do
+        params.merge!(:igmp_snooping_enable => true)
+      end
+
+      it 'configure neutron.conf' do
+        should contain_neutron_config('ovs/igmp_snooping_enable').with_value(true)
+      end
     end
 
   end
 
-  shared_examples 'VPNaaS and FWaaS package installation' do
+  shared_examples 'VPNaaS package installation' do
     before do
       params.merge!(
         :ensure_vpnaas_package => true,
-        :ensure_fwaas_package  => true,
       )
     end
 
     it 'should install *aaS packages' do
-      should contain_package('neutron-fwaas')
       should contain_package('neutron-vpnaas-agent')
     end
   end
@@ -329,13 +377,22 @@ describe 'neutron::server' do
       let (:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          {
-            :server_package => 'neutron-server',
-            :server_service => 'neutron-server'
-          }
+          if facts[:operatingsystem] == 'Ubuntu'
+            {
+              :server_package   => 'neutron-server',
+              :server_service   => 'neutron-server',
+              :rpc_service_name => 'neutron-rpc-server',
+            }
+          else
+            {
+              :api_service_name => 'neutron-api',
+              :rpc_service_name => 'neutron-rpc-server',
+            }
+          end
         when 'RedHat'
           {
-            :server_service => 'neutron-server'
+            :server_service   => 'neutron-server',
+            :rpc_service_name => 'neutron-rpc-server',
           }
         end
       end
